"""
Plot module for spotdesirability.

This module provides plotting utilities for visualizing
Central Composite Designs and other experimental designs.
"""

from spotdesirability.plot.ccd import plotCCD

__all__ = [
    "plotCCD",
]
